@@ -6,12 +6,10 @@ import yaml
 
 from rdm.gaps import audit_for_gaps, list_default_checklists
 from rdm.collect import collect_from_files
-from rdm.doctor import check_data_files
 from rdm.hooks import install_hooks
 from rdm.init import init
 from rdm.pull import pull_from_project_manager
 from rdm.render import render_template_to_file
-from rdm.tex import yaml_gfm_to_tex
 from rdm.translate import translate_test_results, XML_FORMATS
 from rdm.util import context_from_data_files, print_error, load_yaml
 
@@ -34,9 +32,6 @@ def cli(raw_arguments):
         context = context_from_data_files(args.data_files)
         config = load_yaml(args.config)
         render_template_to_file(config, args.template, context, sys.stdout)
-    elif args.command == 'tex':
-        context = context_from_data_files(args.data_files)
-        yaml_gfm_to_tex(args.input, context, sys.stdout)
     elif args.command == 'init':
         init(args.output)
     elif args.command == 'pull':
@@ -46,10 +41,6 @@ def cli(raw_arguments):
     elif args.command == 'collect':
         snippets = collect_from_files(args.files)
         yaml.dump(snippets, sys.stdout, default_style='|')
-    elif args.command == 'doctor':
-        errors = check_data_files()
-        if errors:
-            exit_code = 1
     elif args.command == 'translate':
         translate_test_results(args.format, args.input, args.output)
     elif args.command == 'gap' and args.list:
@@ -74,11 +65,6 @@ def parse_arguments(arguments):
     render_parser.add_argument('config', help='Path to project `config.yml` file')
     render_parser.add_argument('data_files', nargs='*')
 
-    tex_help = 'translate a yaml+gfm file into a tex file using pandoc'
-    tex_parser = subparsers.add_parser('tex', help=tex_help)
-    tex_parser.add_argument('input')
-    tex_parser.add_argument('data_files', nargs='*')
-
     pull_help = 'pull data from the project management tool'
     pull_parser = subparsers.add_parser('pull', help=pull_help)
     pull_parser.add_argument('config', help='Path to project `config.yml` file')
@@ -97,9 +83,6 @@ def parse_arguments(arguments):
     collect_parser = subparsers.add_parser('collect', help=collect_help)
     collect_parser.add_argument('files', nargs='*')
 
-    doctor_help = 'check your regulatory docs for potential problems'
-    subparsers.add_parser('doctor', help=doctor_help)
-
     translate_help = 'translate test output to create test result yaml file'
     translate_parser = subparsers.add_parser('translate', help=translate_help)
     translate_parser.add_argument('format', choices=XML_FORMATS)
