@@ -1,10 +1,9 @@
-from .audit_notes import AuditNoteExclusionExtension, AuditNoteInclusionExtension
+from .audit_notes import AuditNoteExclusionExtension
 from .section_numbers import SectionNumberExtension
 from .vocabulary_extension import VocabularyExtension
 
 __all__ = [
     'AuditNoteExclusionExtension',
-    'AuditNoteInclusionExtension',
     'SectionNumberExtension',
     'VocabularyExtension',
 ]
